@@ -1,20 +1,53 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
+#
+# Copyright 2021 The NiPreps Developers <nipreps@gmail.com>
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+# We support and encourage derived works from this project, please read
+# about our expectations at
+#
+#     https://www.nipreps.org/community/licensing/
+#
 import os
 
 import nibabel as nb
 
-from nipype.interfaces.base import traits
+from nipype.interfaces.base import traits, InputMultiObject, File
 from nipype.utils.filemanip import fname_presuffix
-from nipype.interfaces.ants.resampling import ApplyTransforms
-from nipype.interfaces.ants.registration import Registration
+from nipype.interfaces.ants.resampling import ApplyTransforms, ApplyTransformsInputSpec
+from nipype.interfaces.ants.registration import (
+    Registration,
+    RegistrationInputSpec as _RegistrationInputSpec,
+)
 from nipype.interfaces.ants.segmentation import (
     N4BiasFieldCorrection as VanillaN4,
     N4BiasFieldCorrectionOutputSpec as VanillaN4OutputSpec,
 )
 
 from .. import __version__
-from .utils import _copyxform
+from ..utils.images import _copyxform
+
+
+class _FixTraitApplyTransformsInputSpec(ApplyTransformsInputSpec):
+    transforms = InputMultiObject(
+        traits.Either(File(exists=True), 'identity'),
+        argstr="%s",
+        mandatory=True,
+        desc="transform files: will be applied in reverse order. For "
+        "example, the last specified transform will be applied first.",
+    )
 
 
 class FixHeaderApplyTransforms(ApplyTransforms):
@@ -24,6 +57,8 @@ class FixHeaderApplyTransforms(ApplyTransforms):
     image
     """
 
+    input_spec = _FixTraitApplyTransformsInputSpec
+
     def _run_interface(self, runtime, correct_return_codes=(0,)):
         # Run normally
         runtime = super(FixHeaderApplyTransforms, self)._run_interface(
@@ -38,6 +73,22 @@ class FixHeaderApplyTransforms(ApplyTransforms):
         return runtime
 
 
+class _FixHeaderRegistrationInputSpec(_RegistrationInputSpec):
+    restrict_deformation = traits.List(
+        traits.List(traits.Range(low=0.0, high=1.0)),
+        desc=(
+            "This option allows the user to restrict the optimization of "
+            "the displacement field, translation, rigid or affine transform "
+            "on a per-component basis. For example, if one wants to limit "
+            "the deformation or rotation of 3-D volume to the  first two "
+            "dimensions, this is possible by specifying a weight vector of "
+            "'1x1x0' for a deformation field or '1x1x0x1x1x0' for a rigid "
+            "transformation.  Low-dimensional restriction only works if "
+            "there are no preceding transformations."
+        ),
+    )
+
+
 class FixHeaderRegistration(Registration):
     """
     A replacement for nipype.interfaces.ants.registration.Registration that
@@ -45,6 +96,8 @@ class FixHeaderRegistration(Registration):
     image
     """
 
+    input_spec = _FixHeaderRegistrationInputSpec
+
     def _run_interface(self, runtime, correct_return_codes=(0,)):
         # Run normally
         runtime = super(FixHeaderRegistration, self)._run_interface(
