@@ -22,6 +22,7 @@
 #
 """Visualization tools."""
 import numpy as np
+import nibabel as nb
 
 from nipype.utils.filemanip import fname_presuffix
 from nipype.interfaces.base import (
@@ -32,19 +33,24 @@ from nipype.interfaces.base import (
     traits,
     isdefined,
 )
-from ..viz.plots import fMRIPlot, compcor_variance_plot, confounds_correlation_plot
+from niworkflows.utils.timeseries import _cifti_timeseries, _nifti_timeseries
+from niworkflows.viz.plots import (
+    fMRIPlot,
+    compcor_variance_plot,
+    confounds_correlation_plot,
+)
 
 
 class _FMRISummaryInputSpec(BaseInterfaceInputSpec):
     in_func = File(exists=True, mandatory=True, desc="")
-    in_mask = File(exists=True, desc="")
+    in_spikes_bg = File(exists=True, desc="")
+    fd = File(exists=True, desc="")
+    dvars = File(exists=True, desc="")
+    outliers = File(exists=True, desc="")
     in_segm = File(exists=True, desc="")
-    in_spikes_bg = File(exists=True, mandatory=True, desc="")
-    fd = File(exists=True, mandatory=True, desc="")
-    fd_thres = traits.Float(0.2, usedefault=True, desc="")
-    dvars = File(exists=True, mandatory=True, desc="")
-    outliers = File(exists=True, mandatory=True, desc="")
     tr = traits.Either(None, traits.Float, usedefault=True, desc="the TR")
+    fd_thres = traits.Float(0.2, usedefault=True, desc="")
+    drop_trs = traits.Int(0, usedefault=True, desc="dummy scans")
 
 
 class _FMRISummaryOutputSpec(TraitedSpec):
@@ -67,28 +73,44 @@ class FMRISummary(SimpleInterface):
             newpath=runtime.cwd,
         )
 
-        dataframe = pd.DataFrame(
-            {
-                "outliers": np.loadtxt(self.inputs.outliers, usecols=[0]).tolist(),
-                # Pick non-standardize dvars (col 1)
-                # First timepoint is NaN (difference)
-                "DVARS": [np.nan]
-                + np.loadtxt(self.inputs.dvars, skiprows=1, usecols=[1]).tolist(),
-                # First timepoint is zero (reference volume)
-                "FD": [0.0]
-                + np.loadtxt(self.inputs.fd, skiprows=1, usecols=[0]).tolist(),
-            }
+        dataframe = pd.DataFrame({
+            "outliers": np.loadtxt(self.inputs.outliers, usecols=[0]).tolist(),
+            # Pick non-standardize dvars (col 1)
+            # First timepoint is NaN (difference)
+            "DVARS": [np.nan]
+            + np.loadtxt(self.inputs.dvars, skiprows=1, usecols=[1]).tolist(),
+            # First timepoint is zero (reference volume)
+            "FD": [0.0]
+            + np.loadtxt(self.inputs.fd, skiprows=1, usecols=[0]).tolist(),
+        }) if (
+            isdefined(self.inputs.outliers)
+            and isdefined(self.inputs.dvars)
+            and isdefined(self.inputs.fd)
+        ) else None
+
+        input_data = nb.load(self.inputs.in_func)
+        seg_file = self.inputs.in_segm if isdefined(self.inputs.in_segm) else None
+        dataset, segments = (
+            _cifti_timeseries(input_data)
+            if isinstance(input_data, nb.Cifti2Image) else
+            _nifti_timeseries(input_data, seg_file)
         )
 
         fig = fMRIPlot(
-            self.inputs.in_func,
-            mask_file=self.inputs.in_mask if isdefined(self.inputs.in_mask) else None,
-            seg_file=self.inputs.in_segm if isdefined(self.inputs.in_segm) else None,
-            spikes_files=[self.inputs.in_spikes_bg],
-            tr=self.inputs.tr,
-            data=dataframe[["outliers", "DVARS", "FD"]],
+            dataset,
+            segments=segments,
+            spikes_files=(
+                [self.inputs.in_spikes_bg]
+                if isdefined(self.inputs.in_spikes_bg) else None
+            ),
+            tr=(
+                self.inputs.tr if isdefined(self.inputs.tr) else
+                _get_tr(input_data)
+            ),
+            confounds=dataframe,
             units={"outliers": "%", "FD": "mm"},
             vlines={"FD": [self.inputs.fd_thres]},
+            nskip=self.inputs.drop_trs,
         ).plot()
         fig.savefig(self._results["out_file"], bbox_inches="tight")
         return runtime
@@ -203,3 +225,25 @@ class ConfoundsCorrelationPlot(SimpleInterface):
             reference=self.inputs.reference_column,
         )
         return runtime
+
+
+def _get_tr(img):
+    """
+    Attempt to extract repetition time from NIfTI/CIFTI header
+
+    Examples
+    --------
+    >>> _get_tr(nb.load(Path(test_data) /
+    ...    'sub-ds205s03_task-functionallocalizer_run-01_bold_volreg.nii.gz'))
+    2.2
+    >>> _get_tr(nb.load(Path(test_data) /
+    ...    'sub-01_task-mixedgamblestask_run-02_space-fsLR_den-91k_bold.dtseries.nii'))
+    2.0
+
+    """
+
+    try:
+        return img.header.matrix.get_index_map(0).series_step
+    except AttributeError:
+        return img.header.get_zooms()[-1]
+    raise RuntimeError("Could not extract TR - unknown data structure type")
